'\"
.\" The definitions below are for supplemental macros used in Tcl/Tk
.\" manual entries.
.\"
.\" .HS name section [date [version]]
.\"	Replacement for .TH in other man pages.  See below for valid
.\"	section names.
.\"
.\" .AP type name in/out [indent]
.\"	Start paragraph describing an argument to a library procedure.
.\"	type is type of argument (int, etc.), in/out is either "in", "out",
.\"	or "in/out" to describe whether procedure reads or modifies arg,
.\"	and indent is equivalent to second arg of .IP (shouldn't ever be
.\"	needed;  use .AS below instead)
.\"
.\" .AS [type [name]]
.\"	Give maximum sizes of arguments for setting tab stops.  Type and
.\"	name are examples of largest possible arguments that will be passed
.\"	to .AP later.  If args are omitted, default tab stops are used.
.\"
.\" .BS
.\"	Start box enclosure.  From here until next .BE, everything will be
.\"	enclosed in one large box.
.\"
.\" .BE
.\"	End of box enclosure.
.\"
.\" .VS
.\"	Begin vertical sidebar, for use in marking newly-changed parts
.\"	of man pages.
.\"
.\" .VE
.\"	End of vertical sidebar.
.\"
.\" .DS
.\"	Begin an indented unfilled display.
.\"
.\" .DE
.\"	End of indented unfilled display.
.\"
'\"	# Heading for Tcl/Tk man pages
.de HS
.ds ^3 \\0
.if !"\\$3"" .ds ^3 \\$3
.if '\\$2'cmds'       .TH \\$1 1 \\*(^3 \\$4
.if '\\$2'lib'        .TH \\$1 3 \\*(^3 \\$4
.if '\\$2'tcl'        .TH \\$1 n \\*(^3 Tcl "Tcl Built-In Commands"
.if '\\$2'tk'         .TH \\$1 n \\*(^3 Tk "Tk Commands"
.if '\\$2'tclc'        .TH \\$1 3 \\*(^3 Tcl "Tcl Library Procedures"
.if '\\$2'tkc'         .TH \\$1 3 \\*(^3 Tk "Tk Library Procedures"
.if '\\$2'tclcmds'         .TH \\$1 1 \\*(^3 Tk "Tcl Applications"
.if '\\$2'tkcmds'         .TH \\$1 1 \\*(^3 Tk "Tk Applications"
.if t .wh -1.3i ^B
.nr ^l \\n(.l
.ad b
..
'\"	# Start an argument description
.de AP
.ie !"\\$4"" .TP \\$4
.el \{\
.   ie !"\\$2"" .TP \\n()Cu
.   el          .TP 15
.\}
.ie !"\\$3"" \{\
.ta \\n()Au \\n()Bu
\&\\$1	\\fI\\$2\\fP	(\\$3)
.\".b
.\}
.el \{\
.br
.ie !"\\$2"" \{\
\&\\$1	\\fI\\$2\\fP
.\}
.el \{\
\&\\fI\\$1\\fP
.\}
.\}
..
'\"	# define tabbing values for .AP
.de AS
.nr )A 10n
.if !"\\$1"" .nr )A \\w'\\$1'u+3n
.nr )B \\n()Au+15n
.\"
.if !"\\$2"" .nr )B \\w'\\$2'u+\\n()Au+3n
.nr )C \\n()Bu+\\w'(in/out)'u+2n
..
'\"	# BS - start boxed text
'\"	# ^y = starting y location
'\"	# ^b = 1
.de BS
.br
.mk ^y
.nr ^b 1u
.if n .nf
.if n .ti 0
.if n \l'\\n(.lu\(ul'
.if n .fi
..
'\"	# BE - end boxed text (draw box now)
.de BE
.nf
.ti 0
.mk ^t
.ie n \l'\\n(^lu\(ul'
.el \{\
.\"	Draw four-sided box normally, but don't draw top of
.\"	box if the box started on an earlier page.
.ie !\\n(^b-1 \{\
\h'-1.5n'\L'|\\n(^yu-1v'\l'\\n(^lu+3n\(ul'\L'\\n(^tu+1v-\\n(^yu'\l'|0u-1.5n\(ul'
.\}
.el \}\
\h'-1.5n'\L'|\\n(^yu-1v'\h'\\n(^lu+3n'\L'\\n(^tu+1v-\\n(^yu'\l'|0u-1.5n\(ul'
.\}
.\}
.fi
.br
.nr ^b 0
..
'\"	# VS - start vertical sidebar
'\"	# ^Y = starting y location
'\"	# ^v = 1 (for troff;  for nroff this doesn't matter)
.de VS
.mk ^Y
.ie n 'mc \s12\(br\s0
.el .nr ^v 1u
..
'\"	# VE - end of vertical sidebar
.de VE
.ie n 'mc
.el \{\
.ev 2
.nf
.ti 0
.mk ^t
\h'|\\n(^lu+3n'\L'|\\n(^Yu-1v\(bv'\v'\\n(^tu+1v-\\n(^Yu'\h'-|\\n(^lu+3n'
.sp -1
.fi
.ev
.\}
.nr ^v 0
..
'\"	# Special macro to handle page bottom:  finish off current
'\"	# box/sidebar if in box/sidebar mode, then invoked standard
'\"	# page bottom macro.
.de ^B
.ev 2
'ti 0
'nf
.mk ^t
.if \\n(^b \{\
.\"	Draw three-sided box if this is the box's first page,
.\"	draw two sides but no top otherwise.
.ie !\\n(^b-1 \h'-1.5n'\L'|\\n(^yu-1v'\l'\\n(^lu+3n\(ul'\L'\\n(^tu+1v-\\n(^yu'\h'|0u'\c
.el \h'-1.5n'\L'|\\n(^yu-1v'\h'\\n(^lu+3n'\L'\\n(^tu+1v-\\n(^yu'\h'|0u'\c
.\}
.if \\n(^v \{\
.nr ^x \\n(^tu+1v-\\n(^Yu
\kx\h'-\\nxu'\h'|\\n(^lu+3n'\ky\L'-\\n(^xu'\v'\\n(^xu'\h'|0u'\c
.\}
.bp
'fi
.ev
.if \\n(^b \{\
.mk ^y
.nr ^b 2
.\}
.if \\n(^v \{\
.mk ^Y
.\}
..
'\"	# DS - begin display
.de DS
.RS
.nf
.sp
..
'\"	# DE - end display
.de DE
.fi
.RE
.sp .5
..
.HS vnc tk
.BS
'\" Note:  do not modify the .SH NAME line immediately below!
.SH NAME
vnc \- Create and manipulate widget displaying VNC desktop
.SH SYNOPSIS
\fBvnc\fI \fIpathName \fR?\fIoptions\fR?
.SH "STANDARD OPTIONS"
.LP
.nf
.ta 4c 8c 12c
\fBbackground\fR	\fBborderWidth\fR	\fBcursor\fR
\fBhighlightBackground\fR	\fBhighlightColor\fR	\fBhighlightThickness\fR
\fBrelief\fR	\fBtakeFocus\fR	\fBxScrollCommand\fR
\fByScrollCommand\fR
.fi
.LP
See the ``options'' manual entry for details on the standard options.
.SH "WIDGET-SPECIFIC OPTIONS"
.ta 4c
.LP
.nf
Name:	\fBfillColor\fR
Class:	\fBFillColor\fR
Command-Line Switch:	\fB\-fill\fR
.fi
.IP
Specifies the background color surrounding the VNC desktop.
.LP
.nf
Name:	\fBheight\fR
Class:	\fBHeight\fR
Command-Line Switch:	\fB\-height\fR
.fi
.IP
Specifies a desired height for the widget. If this option isn't specified,
the wigdet adapts to the size of the VNC desktop.
.LP
.nf
Name:	\fBinfoCommand\fR
Class:	\fBInfoCommand\fR
Command-Line Switch:	\fB\-infocommand\fR
.fi
.IP
Specifies a Tcl command prefix to invoked when a change in connection
state to the VNC server is detected. The command gets one argument
appended which is a Tcl list in ``array get'' format describing
the VNC connection.
.LP
.nf
Name:	\fBwidth\fR
Class:	\fBWidth\fR
Command-Line Switch:	\fB\-width\fR
.fi
.IP
Specifies a desired width for the widget. If this option isn't specified,
the wigdet adapts to the size of the VNC desktop.
.BE

.SH DESCRIPTION
.PP
The \fBvnc\fR command creates a new window (given by the
\fIpathName\fR argument) and makes it into a widget which is
capable of connecting to a VNC server and displaying the
desktop that VNC server serves. Additional options, as described above,
may be specified on the command line or in the option database to
configure the widget such as borders and colors,
The \fBvnc\fR command returns its \fIpathName\fR argument.
At the time this command is invoked, there must not exist a
window named \fIpathName\fR, but \fIpathName\fR's parent must exist.
.PP

.SH "WIDGET COMMAND"
.PP
The \fBvnc\fR command creates a new Tcl command whose
name is \fIpathName\fR. This command may be used to invoke various
operations on the widget. It has the following general form:
.DS C
\fIpathName option \fR?\fIarg arg ...\fR?
.DE
\fIOption\fR and the \fIarg\fRs
determine the exact behavior of the command. The following commands are
possible for \fBvnc\fR widgets:
.TP
\fIpathName \fBcget\fR \fIoption\fR
Returns the current value of the configuration option given by \fIoption\fR.
\fIOption\fR may have any of the values accepted by the \fBvnc\fR command.
.TP
\fIpathName \fBconfigure\fR ?\fIoption\fR? ?\fIvalue option value ...\fR?
Query or modify the configuration options of the widget.
If no \fIoption\fR is specified, returns a list describing all of
the available options for \fIpathName\fR (see \fBTk_ConfigureInfo\fR for
information on the format of this list). If \fIoption\fR is specified
with no \fIvalue\fR, then the command returns a list describing the
one named option (this list will be identical to the corresponding
sublist of the value returned if no \fIoption\fR is specified). If
one or more \fIoption\-value\fR pairs are specified, then the command
modifies the given widget option(s) to have the given value(s); in
this case the command returns an empty string.
\fIOption\fR may have any of the values accepted by the \fBvnc\fR
command.
.TP
\fIpathName \fBconnect\fR \fIvnchost\fR ?\fIvncpass\fR ?\fI\-viewonly\fR \fI\-shared\fR??
Connects the widget to the VNC server \fIvnchost\fR with optional
password \fIvncpass\fR. If no interaction with that desktop is
to be allowed, specify the \fI\-viewonly\fR option.
.TP
\fIpathName \fBdisconnect\fR
Disconnects the widget from the VNC server.
.TP
\fIpathName \fBinfo\fR
Returns an ``array get'' list with information about the VNC
connection.
.TP
\fIpathName \fBsendkey downflag keysym\fR
Sends a key press (\fIdownflag\fR is true) or release (\fIdownflag\fR is false)
event with the decimal value \fIkeysym\fR to the VNC server.
.TP
\fIpathNamefR \fBxview\fR \fIoption args\fR
This command is used to query and change the horizontal position
of the widget's window. It can take any of the following forms:
.RS
.TP
\fIpathName\fR \fBxview\fR
Returns a list containing two elements. Each element is
a real fraction between 0 and 1; together they describe
the portion of the VNC desktop's horizontal span that is
visible in the window. These are the same values passed to
scrollbars via the \fB-xscrollcommand\fR option.
.TP
\fIpathName\fR \fBxview moveto\fR \fIfraction\fR
Adjusts the view in the window so that \fIfraction\fR of the
horizontal span of the VNC desktop is off-screen to the left.
\fIFraction\fR is a fraction between 0 and 1.
.TP
\fIpathName\fR \fBxview scroll\fR \fInumber what\fR
This command shifts the view in the window left or right
according to \fInumber\fR and \fIwhat\fR.\fINumber\fR must be
an integer. \fIWhat\fR must be either \fBunits\fR or \fBpages\fR
or an abbreviation of one of these. If \fIwhat\fR is \fBunits\fR,
the view adjusts left or right by \fInumber\fR pixels;
if it is \fBpages\fR then the view adjusts by
\fInumber\fR half VNC desktop widths.
.RE
.TP
\fIpathNamefR \fByview\fR \fIoption args\fR
This command is used to query and change the vertical position
of the widget's window. It can take any of the following forms:
.RS
.TP
\fIpathName\fR \fByview\fR
Returns a list containing two elements. Each element is
a real fraction between 0 and 1; together they describe
the portion of the VNC desktop's vertical span that is
visible in the window. These are the same values passed to
scrollbars via the \fB-yscrollcommand\fR option.
.TP
\fIpathName\fR \fByview moveto\fR \fIfraction\fR
Adjusts the view in the window so that \fIfraction\fR of the
vertical span of the VNC desktop is off-screen to the top.
\fIFraction\fR is a fraction between 0 and 1.
.TP
\fIpathName\fR \fByview scroll\fR \fInumber what\fR
This command shifts the view in the window top or bottom
according to \fInumber\fR and \fIwhat\fR.\fINumber\fR must be
an integer. \fIWhat\fR must be either \fBunits\fR or \fBpages\fR
or an abbreviation of one of these. If \fIwhat\fR is \fBunits\fR,
the view adjusts top or bottom by \fInumber\fR pixels;
if it is \fBpages\fR then the view adjusts by
\fInumber\fR half VNC desktop heights.
.RE

.SH "DEFAULT BINDINGS"
By default key press and release events, mouse motion and button
press and release events are sent to the VNC server when the
\fBvnc\fR widget has the focus and the connection is not made
with the \fI\-viewonly\fR option. The standard binding for
giving the focus out of the \fBvnc\fR widget is \fB<Control\-Tab>\fR.
This can be globally overriden by a \fBbind VNC <Control\-Tab> ...\fR
command.

.SH KEYWORDS
widget, VNC, virtual network computing
